@@ -11,7 +11,7 @@ use MooseX::Types::Moose qw(
         Bool
         Item
     );######<---------------------------------------------------------  ADD New types here
-use version; our $VERSION = qv('0.024.002');
+use version; our $VERSION = qv('0.024.004');
 if( $ENV{ Smart_Comments } ){
 	use Smart::Comments -ENV;
 	### Smart-Comments turned on for Data-Walk-Prune ...
@@ -246,9 +246,9 @@ Data::Walk::Prune - A way to say what should be removed
     
 	#!perl
 	use Moose::Util qw( with_traits );
-	use Data::Walk::Extracted 0.024;
-	use Data::Walk::Prune 0.024;
-	use Data::Walk::Print 0.024;
+	use Data::Walk::Extracted;
+	use Data::Walk::Prune;
+	use Data::Walk::Print;
 
 	my $edward_scissorhands = with_traits(
 			'Data::Walk::Extracted',
@@ -312,33 +312,35 @@ Data::Walk::Prune - A way to say what should be removed
 =head1 DESCRIPTION
 
 This L<Moose::Role|https://metacpan.org/module/Moose::Manual::Roles> implements the method 
-L<prune_data|/prune_data( %args )>.  It takes a L<tree_ref|/tree_ref This is the primary> 
-and a L<slice_ref|/slice_ref This is a data ref> and uses 
-L<Data::Walk::Extracted|https://metacpan.org/module/Data::Walk::Extracted>.  
-To remove portions of the 'tree_ref' defined by an empty hash ref (no keys) or an empty 
-array ref (no positions) at all required points of the 'slice_ref'.  The 'slice_ref' must 
-match the tree ref up to each slice point.  If the slice points are on a branch of the 
-slice_ref that does not exist on the tree_ref then no cut takes place.
+L<prune_data|/prune_data( %args )>.  It takes a $tree_ref and a $slice_ref and uses 
+L<Data::Walk::Extracted|https://metacpan.org/module/Data::Walk::Extracted>.  To remove 
+portions of the 'tree_ref' defined by an empty hash ref (no keys) or an empty array ref 
+(no positions) at all required points of the 'slice_ref'.  The 'slice_ref' must match the 
+tree ref up to each slice point.  If the slice points are on a branch of the slice_ref that 
+does not exist on the tree_ref then no cut takes place.
 
 =head2 USE
 
 This is a L<Moose::Role|https://metacpan.org/module/Moose::Manual::Roles> specifically 
-designed to be used with L<Data::Walk::Extracted|https://metacpan.org/module/Data::Walk::Extracted>. 
-For information on how to L<join|/my $edward_scissorhands = with_traits(> it to that 
-class at run time. See L<Moose::Util|https://metacpan.org/module/Moose::Util> or 
-L<MooseX::ShortCut::BuildInstance|https://metacpan.org/module/MooseX::ShortCut::BuildInstance> 
-for more class building information.
+designed to be used with L<Data::Walk::Extracted
+|https://metacpan.org/module/Data::Walk::Extracted#Extending-Data::Walk::Extracted>.  
+It can be combined traditionaly to the ~::Extracted class using L<Moose
+|https://metacpan.org/module/Moose::Manual::Roles> methods or for information on how to join 
+this role to Data::Walk::Extracted at run time see L<Moose::Util
+|https://metacpan.org/module/Moose::Util> or L<MooseX::ShortCut::BuildInstance
+|https://metacpan.org/module/MooseX::ShortCut::BuildInstance> for more information.
 
 =head1 Attributes
 
 Data passed to -E<gt>new when creating an instance.  For modification of these attributes 
 see L<Methods|/Methods>.  The -E<gt>new function will either accept fat comma lists or a 
 complete hash ref that has the possible attributes as the top keys.  Additionally 
-L<some attributes|/Supported one shot attributes> that have all the following 
-methods; get_$attribute, set_$attribute, has_$attribute, and clear_$attribute,
-can be passed to L<prune_data|/prune_data( %args )> and will be 
-adjusted for just the run of that method call.  These are called 'one shot' 
-attributes.
+some attributes that have all the following methods; get_$attribute, set_$attribute, 
+has_$attribute, and clear_$attribute, can be passed to L<prune_data
+|/prune_data( %args )> and will be adjusted for just the run of that 
+method call.  These are called 'one shot' attributes.  The class and each role (where 
+applicable) in this package have a list of L<supported one shot attributes
+|/Supported one shot attributes>.
 
 =head2 prune_memory
 
